@@ -15,7 +15,7 @@ This construct creates the required infrastructure for an Image Pipeline:
 * Infrastructure configuration which specifies the infrastructure within which to build and test your EC2 Image Builder image.
 * An instance profile associated with the infrastructure configuration
 * An EC2 Image Builder recipe defines the base image to use as your starting point to create a new image, along with the set of components that you add to customize your image and verify that everything is working as expected.
-* Image Builder uses the AWS Task Orchestrator and Executor (AWSTOE) component management application to orchestrate complex workflows. AWSTOE components are based on YAML documents that define the scripts to customize or test your image
+* Image Builder uses the AWS Task Orchestrator and Executor (AWSTOE) component management application to orchestrate complex workflows. AWSTOE components are based on YAML documents that define the scripts to customize or test your image. Support for multiple components.
 * Image Builder image pipelines provide an automation framework for creating and maintaining custom AMIs and container images.
 
 ## Install
@@ -40,26 +40,29 @@ pip install cdk-image-pipeline
 ---
 
 
-```python
+```typescript
 import { ImagePipeline } from 'cdk-image-pipeline'
 import { Construct } from 'constructs';
 
 // ...
 // Create a new image pipeline with the required properties
 new ImagePipeline(this, "MyImagePipeline", {
-    componentDocPath: 'path/to/component_doc.yml',
-    componentName: 'MyComponent',
+    componentDocuments: ['component_example.yml', 'component_example_2.yml'],
+    componentNames: ['Component', 'Component2'],
+    componentVersions: ['0.0.1', '0.1.0'],
+    kmsKeyAlias: 'alias/my-key',
     profileName: 'ImagePipelineInstanceProfile',
     infraConfigName: 'MyInfrastructureConfiguration',
     imageRecipe: 'MyImageRecipe',
     pipelineName: 'MyImagePipeline',
     parentImage: 'ami-0e1d30f2c40c4c701'
 })
+// ...
 ```
 
 By default, the infrastructure configuration will deploy EC2 instances for the build/test phases into a default VPC using the default security group. If you want to control where the instances are launched, you can specify an existing VPC `SubnetID` and a list of `SecurityGroupIds`. In the example below, a new VPC is created and referenced in the `ImagePipeline` construct object.
 
-```python
+```typescript
 import { ImagePipeline } from 'cdk-image-pipeline'
 import * as ec2 from 'aws-cdk-lib/aws-ec2';
 import { Construct } from 'constructs';
@@ -93,8 +96,10 @@ const private_subnet = vpc.privateSubnets;
 
 
 new ImagePipeline(this, "MyImagePipeline", {
-    componentDocPath: 'path/to/component_doc.yml',
-    componentName: 'MyComponent',
+    componentDocuments: ['component_example.yml', 'component_example_2.yml'],
+    componentNames: ['Component', 'Component2'],
+    componentVersions: ['0.0.1', '0.1.0'],
+    kmsKeyAlias: 'alias/my-key',
     profileName: 'ImagePipelineInstanceProfile',
     infraConfigName: 'MyInfrastructureConfiguration',
     imageRecipe: 'MyImageRecipe',
@@ -103,6 +108,7 @@ new ImagePipeline(this, "MyImagePipeline", {
     securityGroups: [sg.securityGroupId],
     subnetId: private_subnet[0].subnetId,
 })
+// ...
 ```
 
 Python usage:
@@ -115,14 +121,17 @@ from constructs import Construct
 image_pipeline = ImagePipeline(
     self,
     "LatestImagePipeline",
-    component_doc_path="component_example.yml",
-    component_name="Comp4",
+    component_documents=["component_example.yml", "component_example2.yml"],
+    component_names=["Component", "Component2"],
+    component_versions=["0.0.1", "0.1.0"],
+    kms_key_alias="alias/my-key",
     image_recipe="Recipe4",
     pipeline_name="Pipeline4",
     infra_config_name="InfraConfig4",
     parent_image="ami-0e1d30f2c40c4c701",
     profile_name="ImagePipelineProfile4",
 )
+# ...
 ```
 
 ```python
@@ -163,8 +172,10 @@ priv_subnets = vpc.private_subnets
 image_pipeline = ImagePipeline(
     self,
     "LatestImagePipeline",
-    component_doc_path="component_example.yml",
-    component_name="Comp4",
+    component_documents=["component_example.yml", "component_example2.yml"],
+    component_names=["Component", "Component2"],
+    component_versions=["0.0.1", "0.1.0"],
+    kms_key_alias="alias/my-key",
     image_recipe="Recipe4",
     pipeline_name="Pipeline4",
     infra_config_name="InfraConfig4",
@@ -173,6 +184,7 @@ image_pipeline = ImagePipeline(
     security_groups=[sg.security_group_id],
     subnet_id=priv_subnets[0].subnet_id
 )
+# ...
 ```
 
 ### Component Documents
@@ -210,6 +222,19 @@ phases:
             - echo "Hello World! Test.
 ```
 
+### Multiple Components
+
+To specify multiple components, add additional component documents to the `componentDoucments` property. You can also add the names and versions of these components via the `componentNames` and `componentVersions` properties (*See usage examples above*). The components will be associated to the Image Recipe that gets created as part of the construct.
+
+Be sure to update the `imageRecipeVersion` property when making updates to your components after your initial deployment.
+
+### SNS Encryption using KMS
+
+---
+
+
+Specify an alias via the `kmsKeyAlias` property which will be used to encrypt the SNS topic.
+
 ### Infrastructure Configuration Instance Types
 
 ---
@@ -236,6 +261,7 @@ import typing_extensions
 
 from ._jsii import *
 
+import aws_cdk.aws_imagebuilder
 import constructs
 
 
@@ -249,10 +275,12 @@ class ImagePipeline(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        component_doc_path: builtins.str,
-        component_name: builtins.str,
+        component_documents: typing.Sequence[builtins.str],
+        component_names: typing.Sequence[builtins.str],
+        component_versions: typing.Sequence[builtins.str],
         image_recipe: builtins.str,
         infra_config_name: builtins.str,
+        kms_key_alias: builtins.str,
         parent_image: builtins.str,
         pipeline_name: builtins.str,
         profile_name: builtins.str,
@@ -266,10 +294,12 @@ class ImagePipeline(
         '''
         :param scope: -
         :param id: -
-        :param component_doc_path: Relative path to the Image Builder component document.
-        :param component_name: Name of the Component.
+        :param component_documents: Relative path to Image Builder component documents.
+        :param component_names: Names of the Component Documents.
+        :param component_versions: Versions for each component document.
         :param image_recipe: Name of the Image Recipe.
         :param infra_config_name: Name of the Infrastructure Configuration for Image Builder.
+        :param kms_key_alias: KMS Key used to encrypt the SNS topic. Enter an existing KMS Key Alias in your target account/region.
         :param parent_image: The source (parent) image that the image recipe uses as its base environment. The value can be the parent image ARN or an Image Builder AMI ID
         :param pipeline_name: Name of the Image Pipeline.
         :param profile_name: Name of the instance profile that will be associated with the Instance Configuration.
@@ -281,10 +311,12 @@ class ImagePipeline(
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
         '''
         props = ImagePipelineProps(
-            component_doc_path=component_doc_path,
-            component_name=component_name,
+            component_documents=component_documents,
+            component_names=component_names,
+            component_versions=component_versions,
             image_recipe=image_recipe,
             infra_config_name=infra_config_name,
+            kms_key_alias=kms_key_alias,
             parent_image=parent_image,
             pipeline_name=pipeline_name,
             profile_name=profile_name,
@@ -298,15 +330,31 @@ class ImagePipeline(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="imageRecipeComponents")
+    def image_recipe_components(
+        self,
+    ) -> typing.List[aws_cdk.aws_imagebuilder.CfnImageRecipe.ComponentConfigurationProperty]:
+        return typing.cast(typing.List[aws_cdk.aws_imagebuilder.CfnImageRecipe.ComponentConfigurationProperty], jsii.get(self, "imageRecipeComponents"))
+
+    @image_recipe_components.setter
+    def image_recipe_components(
+        self,
+        value: typing.List[aws_cdk.aws_imagebuilder.CfnImageRecipe.ComponentConfigurationProperty],
+    ) -> None:
+        jsii.set(self, "imageRecipeComponents", value)
+
 
 @jsii.data_type(
     jsii_type="cdk-image-pipeline.ImagePipelineProps",
     jsii_struct_bases=[],
     name_mapping={
-        "component_doc_path": "componentDocPath",
-        "component_name": "componentName",
+        "component_documents": "componentDocuments",
+        "component_names": "componentNames",
+        "component_versions": "componentVersions",
         "image_recipe": "imageRecipe",
         "infra_config_name": "infraConfigName",
+        "kms_key_alias": "kmsKeyAlias",
         "parent_image": "parentImage",
         "pipeline_name": "pipelineName",
         "profile_name": "profileName",
@@ -322,10 +370,12 @@ class ImagePipelineProps:
     def __init__(
         self,
         *,
-        component_doc_path: builtins.str,
-        component_name: builtins.str,
+        component_documents: typing.Sequence[builtins.str],
+        component_names: typing.Sequence[builtins.str],
+        component_versions: typing.Sequence[builtins.str],
         image_recipe: builtins.str,
         infra_config_name: builtins.str,
+        kms_key_alias: builtins.str,
         parent_image: builtins.str,
         pipeline_name: builtins.str,
         profile_name: builtins.str,
@@ -337,10 +387,12 @@ class ImagePipelineProps:
         subnet_id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param component_doc_path: Relative path to the Image Builder component document.
-        :param component_name: Name of the Component.
+        :param component_documents: Relative path to Image Builder component documents.
+        :param component_names: Names of the Component Documents.
+        :param component_versions: Versions for each component document.
         :param image_recipe: Name of the Image Recipe.
         :param infra_config_name: Name of the Infrastructure Configuration for Image Builder.
+        :param kms_key_alias: KMS Key used to encrypt the SNS topic. Enter an existing KMS Key Alias in your target account/region.
         :param parent_image: The source (parent) image that the image recipe uses as its base environment. The value can be the parent image ARN or an Image Builder AMI ID
         :param pipeline_name: Name of the Image Pipeline.
         :param profile_name: Name of the instance profile that will be associated with the Instance Configuration.
@@ -352,10 +404,12 @@ class ImagePipelineProps:
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
         '''
         self._values: typing.Dict[str, typing.Any] = {
-            "component_doc_path": component_doc_path,
-            "component_name": component_name,
+            "component_documents": component_documents,
+            "component_names": component_names,
+            "component_versions": component_versions,
             "image_recipe": image_recipe,
             "infra_config_name": infra_config_name,
+            "kms_key_alias": kms_key_alias,
             "parent_image": parent_image,
             "pipeline_name": pipeline_name,
             "profile_name": profile_name,
@@ -374,18 +428,25 @@ class ImagePipelineProps:
             self._values["subnet_id"] = subnet_id
 
     @builtins.property
-    def component_doc_path(self) -> builtins.str:
-        '''Relative path to the Image Builder component document.'''
-        result = self._values.get("component_doc_path")
-        assert result is not None, "Required property 'component_doc_path' is missing"
-        return typing.cast(builtins.str, result)
+    def component_documents(self) -> typing.List[builtins.str]:
+        '''Relative path to Image Builder component documents.'''
+        result = self._values.get("component_documents")
+        assert result is not None, "Required property 'component_documents' is missing"
+        return typing.cast(typing.List[builtins.str], result)
 
     @builtins.property
-    def component_name(self) -> builtins.str:
-        '''Name of the Component.'''
-        result = self._values.get("component_name")
-        assert result is not None, "Required property 'component_name' is missing"
-        return typing.cast(builtins.str, result)
+    def component_names(self) -> typing.List[builtins.str]:
+        '''Names of the Component Documents.'''
+        result = self._values.get("component_names")
+        assert result is not None, "Required property 'component_names' is missing"
+        return typing.cast(typing.List[builtins.str], result)
+
+    @builtins.property
+    def component_versions(self) -> typing.List[builtins.str]:
+        '''Versions for each component document.'''
+        result = self._values.get("component_versions")
+        assert result is not None, "Required property 'component_versions' is missing"
+        return typing.cast(typing.List[builtins.str], result)
 
     @builtins.property
     def image_recipe(self) -> builtins.str:
@@ -401,6 +462,16 @@ class ImagePipelineProps:
         assert result is not None, "Required property 'infra_config_name' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def kms_key_alias(self) -> builtins.str:
+        '''KMS Key used to encrypt the SNS topic.
+
+        Enter an existing KMS Key Alias in your target account/region.
+        '''
+        result = self._values.get("kms_key_alias")
+        assert result is not None, "Required property 'kms_key_alias' is missing"
+        return typing.cast(builtins.str, result)
+
     @builtins.property
     def parent_image(self) -> builtins.str:
         '''The source (parent) image that the image recipe uses as its base environment.
