@@ -12,10 +12,7 @@ import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-image-pipeline",
-    "0.0.11",
-    __name__[0:-6],
-    "cdk-image-pipeline@0.0.11.jsii.tgz",
+    "cdk-image-pipeline", "0.1.4", __name__[0:-6], "cdk-image-pipeline@0.1.4.jsii.tgz"
 )
 
 __all__ = [
